@@ -12,7 +12,8 @@ default_config = {
     },
     'cache': {
         'type': 'builtin',
-        'bind': '127.0.0.1:8081'
+        'host': 'localhost',
+        'port': 8081
     },
     'content': {
         'root': '.',
@@ -29,6 +30,7 @@ default_config = {
         'filename': '.upaccess'
     },
     'markdown': {
+        'cache': False,  # options: False, 'shared', 'worker'
         'extensions': {
             'extra': {},
             'codehilite': {
